aboutsummaryrefslogtreecommitdiffstats
path: root/api
diff options
context:
space:
mode:
authorOndrej Fabry <ofabry@cisco.com>2019-01-31 08:23:02 +0100
committerOndrej Fabry <ofabry@cisco.com>2019-01-31 08:23:02 +0100
commit6476a2b64a2e1ea6c0d695127d726a348cc5c99b (patch)
tree49909ae9800e9eb9af64731141dc899accf5d2d6 /api
parent2323d3ffe6e66ea7ffa40be232aa54c1d24c8651 (diff)
Generator improvements
- all objects are now sorted alphabetically for more consistent output - unions now have constructor generated - log level for warnings was changed to debug - GetAllMessages renamed to GetRegisteredMessages Change-Id: I976453004a2fd8b6cb95ca0acfcef56913bf8d38 Signed-off-by: Ondrej Fabry <ofabry@cisco.com>
Diffstat (limited to 'api')
-rw-r--r--api/api.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/api/api.go b/api/api.go
index 9b7f0ff..57a744e 100644
--- a/api/api.go
+++ b/api/api.go
@@ -126,7 +126,7 @@ func RegisterMessage(x Message, name string) {
registeredMessages[name] = x
}
-// GetAllMessages returns list of all registered messages.
-func GetAllMessages() map[string]Message {
+// GetRegisteredMessages returns list of all registered messages.
+func GetRegisteredMessages() map[string]Message {
return registeredMessages
}